@@ -535,7 +535,11 @@ class Runner:
 
     def get_best_model_output(self):
         """Run the model on the best parameters from the iteration state."""
-        return self.func(self.iteration_state.best_parameters, self.input_data)
+        return self.func(self.iteration_state.best_parameters, self.input_data, **self.func_kwargs)
+
+    def get_initial_model_output(self):
+        """Run the model on the best parameters from the iteration state."""
+        return self.func(self.param_base, self.input_data, **self.func_kwargs)
 
     def plot(self, key='loss', ax=None, fig=None):
         if len(self.history) == 0:
@@ -567,7 +571,7 @@ class Runner:
     def plot_compare_with_observed(
         self, observed_values, ax=None, fig=None,
     ):
-        values = self.func(self.iteration_state.best_parameters, self.input_data)
+        values = self.func(self.iteration_state.best_parameters, self.input_data, **self.func_kwargs)
         try:
             assert type(observed_values) == np.ndarray
             assert type(values) == np.ndarray
